@@ -18,3 +18,11 @@ nds = optimiser.find_non_dominated_objective_vectors()
  (-13, -9, -16, -11),
  (-12, -11, -11, -13),       (-12, -11, -11, -13)}
  (-11, -19, -12, -14)}
+
+
+
+def print_vals(message, values):
+    values = ['M' if value >= GRB.MAXINT
+              else ('-M' if value <= -GRB.MAXINT else str(value))
+              for value in values]
+    print(f"{message}: [ {','.join(values)} ]")
